﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Xml;
using System.Xml.Linq;
using System.Xml.Xsl;
using System.Xml.XPath;
using Fonet;
using System.IO;

namespace XmlPdfTransformace
{
    public class XmlPdfRender
    {
        /// <summary>
        /// Na základě vstupního XML dokumentu a odpovídající šabloně XSLT vrátí objekt XDocument, jehož obsahem jsou formátovací objekty dokumentu XML.
        /// </summary>
        /// <param name="xmlDokument">Dokument XML, ke kterému jsou objekty vytvářeny.</param>
        /// <param name="xslSablona">Šablona k dokumentu XML.</param>
        /// <exception cref="ArgumentException">Neplatné argumenty.</exception>
        /// <returns>Dokument formátovacích objektů typu <see cref="XDocument"/></returns>
        public static XDocument PrevestDoXslFo(XDocument xmlDokument, XDocument xslSablona)
        {
            return PrevestDoXslFo(xmlDokument.CreateNavigator(), xslSablona.CreateNavigator());
        }

        /// <summary>
        /// Na základě vstupního XML dokumentu a odpovídající šabloně XSLT vrátí objekt XDocument, jehož obsahem jsou formátovací objekty dokumentu XML.
        /// </summary>
        /// <param name="xmlDokument">Dokument XML, ke kterému jsou objekty vytvářeny.</param>
        /// <param name="xslSablona">Šablona k dokumentu XML.</param>
        /// <exception cref="ArgumentException">Neplatné argumenty.</exception>
        /// <returns>Dokument formátovacích objektů typu <see cref="XDocument"/></returns>
        public static XDocument PrevestDoXslFo(IXPathNavigable xmlDokument, IXPathNavigable xslSablona)
        {
            if (xmlDokument == null || xslSablona == null)
                throw new ArgumentException("Neplatné argumenty");

            using(MemoryStream xslFoStream = new MemoryStream())
            {
                XmlWriterSettings settings = new System.Xml.XmlWriterSettings();
                settings.Encoding = new UTF8Encoding(false);
                settings.ConformanceLevel = ConformanceLevel.Document;
                settings.Indent = true;

                using (XmlWriter xwriter = XmlWriter.Create(xslFoStream, settings))
                {
                    XslCompiledTransform transformer = new XslCompiledTransform(false);

                    transformer.Load(xslSablona.CreateNavigator());
                    transformer.Transform(xmlDokument.CreateNavigator(), null, xwriter);

                    xwriter.Flush();
                }

                string transformedXml = Encoding.UTF8.GetString(xslFoStream.ToArray());
                return XDocument.Parse(transformedXml);
                
            }
        }

        /// <summary>
        /// Vytvoří PDF dokument ze vstupního souboru obsahujícího formátovací objekty XSL-FO.
        /// </summary>
        /// <param name="xslFoDoc">Vstupní soubor XSL-FO.</param>
        /// <param name="url">Cesta k uložení souboru.</param>
        /// <exception cref="ArgumentException">Neplatné argumenty.</exception>
        public static void TransformaceDoPdf(XDocument xslFoDoc, string url)
        {
            if (xslFoDoc == null || url == null)
                throw new ArgumentException("Nepltané argumenty");
            FonetDriver driver = FonetDriver.Make();
            FileStream stream = new FileStream(url, FileMode.Create);
            
            driver.Render(xslFoDoc.CreateReader(), stream);
        }

        /// <summary>
        /// Vytvoří PDF dokument na základě šablony stylů pro vstupní dokument XML a uloží jej na vybrané místo na disku.
        /// </summary>
        /// <param name="xmlDokument">Vstupní dokument XML.</param>
        /// <param name="xslSablona">Šablona stylů pro data z XML dokumentu.</param>
        /// <param name="url">Místo pro uložení výsledného PDF souboru na disk.</param>
        public static void TransformaceDoPdf(IXPathNavigable xmlDokument, IXPathNavigable xslSablona, string url)
        {
            TransformaceDoPdf(PrevestDoXslFo(xmlDokument, xslSablona), url);
        }
    }
}
