﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

using System.Xml.Linq;
using System.Xml.XPath;
using ColorCode;

using XmlPdfTransformace;


namespace TemplateCreator
{
    public partial class Form1 : Form
    {
        private XDocument xml;
        private PoleObdelniku poleObdelniku;
        private bool pridatObdelnik = false;
        private Graphics grafika;
        private Obdelnik aktivniObdelnik;

        private Format format;
        private IList<FontFamily> fontKolekce;
        private IList<float> fontVelikost;
        private FontFamily aktualniFont;
        private float aktualniVelikostFontu;
        private Color aktualniBarvaPisma;


        public Form1()
        {
            InitializeComponent();
            poleObdelniku = new PoleObdelniku();
            grafika = grafickePlatno.CreateGraphics();
            grafickePlatno.AllowDrop = true;
            grafickePlatno.Width = CentimeterToPixel(21);
            grafickePlatno.Height = CentimeterToPixel(29.7);

            panel1.AutoScroll = true;
            grafickePlatno.SizeMode = PictureBoxSizeMode.AutoSize;
            grafickePlatno.BackColor = SystemColors.ControlDark;
            pravitko.Visible = false;


            this.KeyPreview = true;

            TableLayoutColumnStyleCollection styles = this.tableLayoutPanel1.ColumnStyles;

            foreach (ColumnStyle item in styles)
            {
                if (item.SizeType == SizeType.Absolute && item.Width != 300)
                {
                    item.Width = CentimeterToPixel(21);
                }
            }

            fontKolekce = FontFamily.Families.Select(f => f).ToList();
            aktualniVelikostFontu = 10;
            aktualniFont = new FontFamily("Calibri");
            aktualniBarvaPisma = Color.Black;

            foreach (var item in fontKolekce)
            {
                cmbFont.Items.Add(item.Name);
            }


            fontVelikost = new List<float>() { 8f, 9f, 10f, 11f, 12f, 14f, 16f, 18f, 20f, 22f, 24f, 26f, 28f, 36f, 48f, 72f };
            foreach (var item in fontVelikost)
            {
                cmbFontSize.Items.Add(item.ToString());
            }


        }

        #region Načtení XML dokumentu do TreeView
        private void NactiXmlDoTreeView(XDocument x)
        {
            ImageList il = new ImageList();
            il.Images.Add(Properties.Resources.application_view_list);
            il.Images.Add(Properties.Resources.textfield);
            xmlTreeView.ImageList = il;

            xmlTreeView.Nodes.Clear();
            xmlTreeView.Nodes.Add(new TreeNode(x.Root.Name.ToString(), 0, 0));
            TreeNode treeNode = new TreeNode();
            treeNode = xmlTreeView.Nodes[0];
            AddElement(x.Root, treeNode);
        }

        private void AddElement(XElement inElement, TreeNode inTreeNode)
        {
            IEnumerable<XElement> elements;
            TreeNode treeNode;

            if (inElement.HasElements)
            {
                elements = inElement.Elements();
                int i = 0;
                foreach (XElement el in elements)
                {
                    inTreeNode.Nodes.Add(new TreeNode(el.Name.ToString()));
                    treeNode = inTreeNode.Nodes[i++];
                    AddElement(el, treeNode);
                }
            }
            else
            {
                //inTreeNode.Nodes.Add(new TreeNode(inElement.Value, 1, 1));
            }
            xmlTreeView.ExpandAll();
        }




        private void načíctXMLToolStripMenuItem_Click(object sender, EventArgs e)
        {
            OpenFileDialog odlg = new OpenFileDialog();
            odlg.DefaultExt = ".xml";
            odlg.Filter = "XML Documents (.xml)|*.xml";

            if (odlg.ShowDialog() == DialogResult.OK)
            {
                string filename = odlg.FileName;
                try
                {
                    xml = XDocument.Load(filename);
                    NactiXmlDoTreeView(xml);
                    pravitko.Visible = true;
                    grafickePlatno.BackColor = Color.White;
                    btnPridatObdelnik.Enabled = true;
                    toolStripStatusLabel1.Text = "Načten XML dokument: " + filename;
                }
                catch (Exception)
                {
                    MessageBox.Show("Soubor: " + filename + " se nepovedlo načíst, pravděpodobně není validní.", "Chyba",MessageBoxButtons.OK, MessageBoxIcon.Error);
                    toolStripStatusLabel1.Text = "Soubor: " + filename + " se nepovedlo načíst, pravděpodobně není validní.";
                }
                
            }
            else
            {
                toolStripStatusLabel1.Text = "Soubor nebyl vybrán!";
            }
        }

        #endregion

        private void btnPridatObdelnik_Click(object sender, EventArgs e)
        {
            if (pridatObdelnik)
            {
                pridatObdelnik = false;
                btnPridatObdelnik.FlatStyle = FlatStyle.Standard;
            }
            else
            {
                pridatObdelnik = true;
                btnPridatObdelnik.FlatStyle = FlatStyle.Flat;
            }
        }

        private void grafickePlatno_MouseClick(object sender, MouseEventArgs e)
        {
            if (pridatObdelnik)
            {
                if (aktivniObdelnik != null)
                    aktivniObdelnik.JeVybran = false;
                Rectangle r = new Rectangle(e.X, e.Y, 150, 30);
                aktivniObdelnik = new Obdelnik(r);
                poleObdelniku.PridejObdelnik(aktivniObdelnik);
                aktivniObdelnik.NastavitPictureBox(grafickePlatno);
                aktivniObdelnik.JeVybran = true;
                pridatObdelnik = false;
                btnPridatObdelnik.FlatStyle = FlatStyle.Standard;
            }

            grafickePlatno.Invalidate();
        }

        private void grafickePlatno_Paint(object sender, PaintEventArgs e)
        {




        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.xmlTreeView.ItemDrag += new System.Windows.Forms.ItemDragEventHandler(this.xmlTreeView_ItemDrag);
            this.grafickePlatno.DragEnter += grafickePlatno_DragEnter;
            this.grafickePlatno.DragDrop += grafickePlatno_DragDrop;
            this.grafickePlatno.MouseHover += grafickePlatno_MouseHover;
            this.grafickePlatno.MouseWheel += grafickePlatno_MouseWheel;
        }

        void grafickePlatno_MouseWheel(object sender, MouseEventArgs e)
        {
            // skrolování na grafickém plátně
        }

        void grafickePlatno_MouseHover(object sender, EventArgs e)
        {
            grafickePlatno.Focus();
        }




        void grafickePlatno_DragDrop(object sender, DragEventArgs e)
        {
            TreeNode tNode = (TreeNode)e.Data.GetData("System.Windows.Forms.TreeNode");

            if (tNode.Parent == null)
            {
                MessageBox.Show("Kořenový element nelze vložit do dokumentu!", "Varování", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                return;
            }

            string cesta = SestavXPath(tNode);
            Point bod = grafickePlatno.PointToClient(new Point(e.X, e.Y));

            if (poleObdelniku.NajdiNaPozici(bod) != null) // jestliže byl prvek upuštěn na obdélníku
            {
                Format f = new Format();
                f.VelikostPisma = aktualniVelikostFontu;
                f.JmenoFontu = aktualniFont;
                f.BarvaPisma = aktualniBarvaPisma;
                f.StylPisma = FontStyle.Regular;
                f.Xpath = cesta;
                f.NazevElementu = tNode.Text;
                poleObdelniku.NajdiNaPozici(bod).FormatPisma = f;

                format = f;
                propertyGrid.SelectedObject = format;

                if (tNode.FirstNode == null)
                {
                    poleObdelniku.NajdiNaPozici(bod).Typ = Obdelnik.TypObsahu.JednoduchyBlok;
                    poleObdelniku.NajdiNaPozici(bod).Obsah = cesta;
                }
                else
                {
                    TreeNodeCollection t = tNode.Nodes;
                    string nazevPodruzenehoUzlu = tNode.FirstNode.Text;

                    bool jeTabulkou = false;
                    foreach (TreeNode item in t)
                    {
                        if (item.Text == nazevPodruzenehoUzlu)
                            jeTabulkou = true;
                        else jeTabulkou = false;
                    }

                    if (jeTabulkou)
                    {
                        poleObdelniku.NajdiNaPozici(bod).Typ = Obdelnik.TypObsahu.Tabulka;
                        TabulkaXsl tbl = new TabulkaXsl();
                        tbl.SirkaTabulky = poleObdelniku.NajdiNaPozici(bod).obdelnik.Width;
                        tbl.Data = tNode;
                        tbl.XmlData = xml;

                        int pocetElementu = tNode.FirstNode.Nodes.Count;
                        for (int i = 0; i < pocetElementu; i++)
                        {
                            tbl.Nadpisy.Add("Nadpis " + i);
                            tbl.SirkySloupcu.Add(100);
                        }

                        using (Tabulka tabulkaDialog = new Tabulka())
                        {
                            tabulkaDialog.Tbl = tbl;
                            tabulkaDialog.ShowDialog();
                            poleObdelniku.NajdiNaPozici(bod).Obsah = cesta;
                            poleObdelniku.NajdiNaPozici(bod).tabulka = tbl;
                            poleObdelniku.NajdiNaPozici(bod).obdelnik.Width = tbl.SirkaTabulky;
                        }
                    }
                    else
                    {
                        poleObdelniku.NajdiNaPozici(bod).Typ = Obdelnik.TypObsahu.SlozenyBlok;
                        SlozenyBlokXsl slb = new SlozenyBlokXsl();
                        slb.NaplnitSeznam(tNode);
                        poleObdelniku.NajdiNaPozici(bod).slozenyBlok = slb;
                        poleObdelniku.NajdiNaPozici(bod).Obsah = cesta;
                    }
                }

                cmbFontSize.SelectedIndex = DejIndexVelikostiFontu((int)Math.Round(format.Font.Size));
                cmbFont.SelectedIndex = DejIndexFontu(format.Font.FontFamily);


                cmbFont.Enabled = cmbFontSize.Enabled = btnBold.Enabled = btnItalic.Enabled = btnUnderline.Enabled = btnVyberBarvu.Enabled =
                btnAlignCenter.Enabled = btnAlignJustify.Enabled = btnAlignRight.Enabled = btnAlignLeft.Enabled = nudTop.Enabled = true;

                nudTop.Value = (int)format.Mezera;

                StatusTlacitek();
                grafickePlatno.Invalidate();
            }
            else
            {
                MessageBox.Show("Na této pozici neexistuje žádný blok. Nejprve jej vytvořte a poté ho naplňte daty.", "Varování", MessageBoxButtons.OK, MessageBoxIcon.Warning);
            }
        }

        private int DejIndexFontu(FontFamily f)
        {
            return fontKolekce.IndexOf(f);
        }

        private int DejIndexVelikostiFontu(float v)
        {
            return fontVelikost.IndexOf(v);
        }

        void grafickePlatno_DragEnter(object sender, DragEventArgs e)
        {
            e.Effect = DragDropEffects.Move;
        }

        private void xmlTreeView_ItemDrag(object sender, ItemDragEventArgs e)
        {
            DoDragDrop(e.Item, DragDropEffects.Move);
        }

        int CentimeterToPixel(double Centimeter)
        {
            double pixel = -1;
            using (Graphics g = this.CreateGraphics())
            {
                pixel = Centimeter * g.DpiY / 2.54d;
            }
            return (int)pixel;
        }

        double PixelToCentimeter(int pixel)
        {
            double centimeter = -1;
            using (Graphics g = this.CreateGraphics())
            {
                centimeter = (pixel * 2.54d) / g.DpiY;
            }
            return centimeter;
        }

        #region Sestav XPath
        private string NajdiPoziciVeStromu(TreeNode tnode)
        {
            string path = "";
            string uzel = tnode.Text;
            int i = 0;
            int index = 0;

            TreeNodeCollection n = tnode.Parent.Nodes;
            foreach (TreeNode item in n)
            {
                if (item.Text == tnode.Text)
                    i++;
                if (((object)tnode).Equals((object)item))
                {
                    index = i;
                }
            }

            if (i > 1)
            {
                path = uzel + "[" + index + "]";
            }
            else path = uzel;

            return path;
        }

        private string SestavXPath(TreeNode tnode)
        {
            string path = "";
            while (tnode.Parent != null && tnode.Parent.GetType() == typeof(TreeNode))
            {
                path = NajdiPoziciVeStromu(tnode) + "/" + path;
                tnode = tnode.Parent;
            }
            path = path.Remove(path.Length - 1);
            return path;
        }

        #endregion

        private void uložitJakoPDFToolStripMenuItem_Click(object sender, EventArgs e)
        {
            saveFileDialog1.Filter = "pdf files (*.pdf)|*.pdf";
            saveFileDialog1.RestoreDirectory = true;
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                //XmlPdfRender.TransformaceDoPdf(xslFo, saveFileDialog1.FileName);
                try
                {
                    XmlPdfRender.TransformaceDoPdf(xml.CreateNavigator(), (XDocument.Parse(poleObdelniku.SestavitXsl(this.CreateGraphics()))).CreateNavigator(), saveFileDialog1.FileName);
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Při ukládání došlo k chybě. " + ex.Message + "Pravděpodobně v dokumentu existují prázdná pole, která je potřeba naplnit daty, nebo odstanit.", "Chyba při ukládání...", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }


            //XDocument fo = XmlPdfTransformace.XmlPdfRender.PrevestDoXslFo(xml, XDocument.Parse(poleObdelniku.SestavitXsl(this.CreateGraphics())));
            //richTextBox1.Text = fo.ToString();
        }

        private void Form1_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Delete)
            {
                if (poleObdelniku.OdeberObdelnik(aktivniObdelnik))
                {
                    aktivniObdelnik.OdeberPictureBox();
                    grafickePlatno.Invalidate();
                }
            }

        }

        private void kódŠablonyXSLToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                XDocument doc = XDocument.Parse(poleObdelniku.SestavitXsl(this.CreateGraphics()));
                string kod = new CodeColorizer().Colorize(doc.ToString(), Languages.Xml);
                using (NahledXslKodu nahled = new NahledXslKodu())
                {
                    nahled.Kod = kod;
                    nahled.ShowDialog();
                }
            }
            catch (Exception)
            {

                MessageBox.Show("Kód šablony XSL není validní, pravděpodobně jste udělali chybu při návrhu, opravte jej!", "Chyba...", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        private void NastavPravitko(Graphics gPravitko)
        {
            for (double i = 0; i < 42; i += 0.5)
            {
                int vzdalenost = CentimeterToPixel(i);
                if (i % 1 > 0)
                {
                    Point zacatek = new Point(vzdalenost, 3);
                    Point konec = new Point(vzdalenost, 7);
                    gPravitko.DrawLine(Pens.Gray, zacatek, konec);
                }
                else
                {
                    string s = i.ToString();
                    float x = (float)vzdalenost - 4;
                    float y = -1.0f;
                    gPravitko.DrawString(i.ToString(), new Font("Arial", 8), Brushes.Gray, new PointF(x, y));
                }

            }
        }

        private void pravitko_Paint(object sender, PaintEventArgs e)
        {
            pravitko.Width = CentimeterToPixel(21);
            this.Width = CentimeterToPixel(21);
            NastavPravitko(e.Graphics);
        }

        private void grafickePlatno_MouseDown(object sender, MouseEventArgs e)
        {
            if (aktivniObdelnik != null)
            {
                aktivniObdelnik.JeVybran = false;
                //aktivniObdelnik = null;
                if (poleObdelniku.NajdiNaPozici(e.Location) != null)
                {
                    aktivniObdelnik = poleObdelniku.NajdiNaPozici(e.Location);
                    aktivniObdelnik.JeVybran = true;
                    aktivniObdelnik.NastavitPictureBox(grafickePlatno);

                    if (aktivniObdelnik.FormatPisma != null)
                    {
                        format = aktivniObdelnik.FormatPisma;
                        nudTop.Value = (int)format.Mezera;
                        panelBarvaNahled.BackColor = format.BarvaPisma;
                        propertyGrid.SelectedObject = format;
                        cmbFontSize.SelectedIndex = DejIndexVelikostiFontu((int)Math.Round(format.Font.Size));
                        cmbFont.SelectedIndex = DejIndexFontu(format.Font.FontFamily);
                        StatusTlacitek();
                        cmbFont.Enabled = cmbFontSize.Enabled = btnBold.Enabled = btnItalic.Enabled = btnUnderline.Enabled = btnVyberBarvu.Enabled =
                        btnAlignCenter.Enabled = btnAlignJustify.Enabled = btnAlignRight.Enabled = btnAlignLeft.Enabled = nudTop.Enabled = true;
                    }
                }
                else
                {
                    cmbFont.Enabled = cmbFontSize.Enabled = btnBold.Enabled = btnItalic.Enabled = btnUnderline.Enabled = btnVyberBarvu.Enabled =
                    btnAlignCenter.Enabled = btnAlignJustify.Enabled = btnAlignRight.Enabled = btnAlignLeft.Enabled = nudTop.Enabled = false;
                }
            }


            grafickePlatno.Invalidate();
        }

        private void grafickePlatno_DoubleClick(object sender, EventArgs e)
        {


            Point bod = grafickePlatno.PointToClient(new Point(MousePosition.X, MousePosition.Y));
            if (poleObdelniku.NajdiNaPozici(bod) != null)
            {
                if (poleObdelniku.NajdiNaPozici(bod).Typ == Obdelnik.TypObsahu.Tabulka)
                {
                    using (Tabulka tabulkaDialog = new Tabulka())
                    {
                        tabulkaDialog.Tbl = poleObdelniku.NajdiNaPozici(bod).tabulka;
                        tabulkaDialog.ShowDialog();
                        poleObdelniku.NajdiNaPozici(bod).obdelnik.Width = poleObdelniku.NajdiNaPozici(bod).tabulka.SirkaTabulky;
                        grafickePlatno.Invalidate();
                    }
                }
            }
        }

        private void cmbFont_SelectedIndexChanged(object sender, EventArgs e)
        {
            aktualniFont = fontKolekce.ElementAt(cmbFont.SelectedIndex);
            format.JmenoFontu = aktualniFont;
            propertyGrid.SelectedObject = format;
        }

        private void cmbFontSize_SelectedIndexChanged(object sender, EventArgs e)
        {
            aktualniVelikostFontu = fontVelikost.ElementAt(cmbFontSize.SelectedIndex);
            format.VelikostPisma = aktualniVelikostFontu;
            propertyGrid.SelectedObject = format;
        }

        private void propertyGrid_PropertyValueChanged(object s, PropertyValueChangedEventArgs e)
        {

            format.ZmenaVlastnostiFormularem();
            cmbFontSize.SelectedIndex = DejIndexVelikostiFontu((int)Math.Round(format.Font.Size));
            cmbFont.SelectedIndex = DejIndexFontu(format.Font.FontFamily);
            panelBarvaNahled.BackColor = format.BarvaPisma;
            aktualniBarvaPisma = format.BarvaPisma;
            StatusTlacitek();
        }

        private void btnVyberBarvu_Click(object sender, EventArgs e)
        {
            if (colorDialog1.ShowDialog() == DialogResult.OK)
            {
                aktualniBarvaPisma = colorDialog1.Color;
                format.BarvaPisma = aktualniBarvaPisma;
                panelBarvaNahled.BackColor = aktualniBarvaPisma;
                propertyGrid.SelectedObject = format;
            }
        }

        private void StatusTlacitek()
        {
            FontStyle styl = format.Font.Style;
            Color barva = Color.PeachPuff;
            Color prazdna = Color.Empty;

            if ((styl & FontStyle.Bold) == 0)
            {
                btnBold.BackColor = prazdna;
            }
            else
                btnBold.BackColor = barva;

            if ((styl & FontStyle.Italic) == 0)
            {
                btnItalic.BackColor = prazdna;
            }
            else
                btnItalic.BackColor = barva;

            if ((styl & FontStyle.Underline) == 0)
            {
                btnUnderline.BackColor = prazdna;
            }
            else
                btnUnderline.BackColor = barva;

            switch (format.ZarovnaniPisma)
            {
                case (Zarovnani.CENTER):
                    VybratCenter();
                    break;
                case (Zarovnani.LEFT):
                    VybratLeft();
                    break;
                case (Zarovnani.RIGHT):
                    VybratRight();
                    break;
                case (Zarovnani.JUSTIFY):
                    VybratJustify();
                    break;
            }
        }



        private void ZmenStyl(FontStyle stylElementu, FontStyle stylTlacitka, Button b)
        {
            if ((stylElementu & stylTlacitka) == 0)
            {
                stylElementu |= stylTlacitka;
                format.StylPisma = stylElementu;
                b.BackColor = Color.PeachPuff;
                propertyGrid.SelectedObject = format;
            }
            else if ((stylElementu & stylTlacitka) != 0)
            {
                stylElementu &= ~stylTlacitka;
                format.StylPisma = stylElementu;
                b.BackColor = Color.Empty;
                propertyGrid.SelectedObject = format;
            }

        }

        private void btnItalic_Click(object sender, EventArgs e)
        {
            ZmenStyl(format.Font.Style, FontStyle.Italic, btnItalic);
        }

        private void btnBold_Click(object sender, EventArgs e)
        {
            ZmenStyl(format.Font.Style, FontStyle.Bold, btnBold);
        }

        private void btnUnderline_Click(object sender, EventArgs e)
        {
            ZmenStyl(format.Font.Style, FontStyle.Underline, btnUnderline);
        }

        #region Formát fontu

        private void btnAlignLeft_Click(object sender, EventArgs e)
        {
            if (format.ZarovnaniPisma != Zarovnani.LEFT)
            {
                format.ZarovnaniPisma = Zarovnani.LEFT;
                propertyGrid.SelectedObject = format;
                VybratLeft();
            }

        }

        private void btnAlignCenter_Click(object sender, EventArgs e)
        {
            if (format.ZarovnaniPisma != Zarovnani.CENTER)
            {
                format.ZarovnaniPisma = Zarovnani.CENTER;
                propertyGrid.SelectedObject = format;
                VybratCenter();
            }
        }

        private void btnAlignRight_Click(object sender, EventArgs e)
        {
            if (format.ZarovnaniPisma != Zarovnani.RIGHT)
            {
                format.ZarovnaniPisma = Zarovnani.RIGHT;
                propertyGrid.SelectedObject = format;
                VybratRight();
            }
        }

        private void btnAlignJustify_Click(object sender, EventArgs e)
        {
            if (format.ZarovnaniPisma != Zarovnani.JUSTIFY)
            {
                format.ZarovnaniPisma = Zarovnani.JUSTIFY;
                propertyGrid.SelectedObject = format;
                VybratJustify();
            }
        }

        private void VybratCenter()
        {
            btnAlignLeft.BackgroundImage = Properties.Resources.left;
            btnAlignCenter.BackgroundImage = Properties.Resources.center_color;
            btnAlignJustify.BackgroundImage = Properties.Resources.justify;
            btnAlignRight.BackgroundImage = Properties.Resources.right;
        }

        private void VybratLeft()
        {
            btnAlignLeft.BackgroundImage = Properties.Resources.left_color;
            btnAlignCenter.BackgroundImage = Properties.Resources.center;
            btnAlignJustify.BackgroundImage = Properties.Resources.justify;
            btnAlignRight.BackgroundImage = Properties.Resources.right;
        }

        private void VybratJustify()
        {
            btnAlignLeft.BackgroundImage = Properties.Resources.left;
            btnAlignCenter.BackgroundImage = Properties.Resources.center;
            btnAlignJustify.BackgroundImage = Properties.Resources.justify_color;
            btnAlignRight.BackgroundImage = Properties.Resources.right;
        }

        private void VybratRight()
        {
            btnAlignLeft.BackgroundImage = Properties.Resources.left;
            btnAlignCenter.BackgroundImage = Properties.Resources.center;
            btnAlignJustify.BackgroundImage = Properties.Resources.justify;
            btnAlignRight.BackgroundImage = Properties.Resources.right_color;
        }

        #endregion

        private void nudTop_ValueChanged(object sender, EventArgs e)
        {
            format.Mezera = (float)nudTop.Value;
            propertyGrid.SelectedObject = format;
        }

        private void uložitŠablonuXSLToolStripMenuItem_Click(object sender, EventArgs e)
        {


            saveFileDialog1.Filter = "XSL files (*.xsl)|*.xsl";
            saveFileDialog1.RestoreDirectory = true;
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                //XmlPdfRender.TransformaceDoPdf(xslFo, saveFileDialog1.FileName);
                try
                {
                    XDocument sablona = XDocument.Parse(poleObdelniku.SestavitXsl(this.CreateGraphics()));
                    sablona.Save(saveFileDialog1.FileName);
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Při ukládání došlo k chybě. " + ex.Message + "Pravděpodobně v dokumentu existují prázdná pole, která je potřeba naplnit daty, nebo odstanit.", "Chyba při ukládání...", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }

            }
        }

        private void kódXSLTFOToolStripMenuItem_Click(object sender, EventArgs e)
        {

            try
            {
                XDocument doc = XDocument.Parse(poleObdelniku.SestavitXsl(this.CreateGraphics()));
                doc = XmlPdfTransformace.XmlPdfRender.PrevestDoXslFo(xml, doc);
                string kod = new CodeColorizer().Colorize(doc.ToString(), Languages.Xml);
                using (NahledXslKodu nahled = new NahledXslKodu())
                {
                    nahled.Kod = kod;
                    nahled.ShowDialog();
                }
            }
            catch (Exception)
            {

                MessageBox.Show("Kód šablony XSL není validní, pravděpodobně jste udělali chybu při návrhu, opravte jej!", "Chyba...", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void uložitXSLFOToolStripMenuItem_Click(object sender, EventArgs e)
        {

            saveFileDialog1.Filter = "XSL-FO files (*.xslfo)|*.xslfo";
            saveFileDialog1.RestoreDirectory = true;
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                //XmlPdfRender.TransformaceDoPdf(xslFo, saveFileDialog1.FileName);
                try
                {
                    XDocument doc = XDocument.Parse(poleObdelniku.SestavitXsl(this.CreateGraphics()));
                    doc = XmlPdfTransformace.XmlPdfRender.PrevestDoXslFo(xml, doc);
                    doc.Save(saveFileDialog1.FileName);
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Při ukládání došlo k chybě. " + ex.Message + "Pravděpodobně v dokumentu existují prázdná pole, která je potřeba naplnit daty, nebo odstanit.", "Chyba při ukládání...", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }

            }
        }

    }
}
