﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using System.ComponentModel;
using System.Drawing;

namespace TemplateCreator
{
    public class Format
    {
        private string xpath;
        private string nazevElementu;
        private Font font;
        private FontFamily jmenoFontu;
        private FontStyle stylPisma;
        private float velikostPisma;
        private Color barvaPisma;
        private Zarovnani zarovnaniPisma;
        private float mezera = 0;


        [ReadOnly(true)]
        [CategoryAttribute("Element"), DescriptionAttribute("Název elementru v dokumentu XML. Je zároveň cestou k tomuto konkrétnímu elementu (XPath).")]
        public string Xpath
        {
            get { return xpath; }
            set
            {
                xpath = value;
            }
        }

        [CategoryAttribute("Vlastnosti písma"), DescriptionAttribute("Umožňuje prohlížet a změnit některé parametry písma."), DisplayName("Písmo")]
        public Font Font
        {
            get { return font; }
            set
            {
                font = value;
            }
        }

        [CategoryAttribute("Vlastnosti písma"), DescriptionAttribute("Bold, Italic, Underline, Strikeout"), DisplayName("Styl písma")]
        public FontStyle StylPisma
        {
            get { return stylPisma; }
            set
            {
                stylPisma = value;
                SestavFont();
            }
        }

        [ReadOnly(true)]
        [CategoryAttribute("Vlastnosti písma"), DisplayName("Velikost písma"), DescriptionAttribute("Velikost písma v dokumentu")]
        public float VelikostPisma
        {
            get { return velikostPisma; }
            set
            {
                velikostPisma = value;
                SestavFont();
            }
        }

        [ReadOnly(true)]
        [CategoryAttribute("Element"), DisplayName("Název elementu")]
        public string NazevElementu
        {
            get
            {
                return nazevElementu;
            }
            set
            {
                nazevElementu = value;
            }
        }

        [CategoryAttribute("Vlastnosti písma"), DisplayName("Název fontu")]
        public FontFamily JmenoFontu
        {
            get
            {
                return jmenoFontu;
            }
            set
            {
                jmenoFontu = value;
                SestavFont();
            }
        }

        [CategoryAttribute("Vlastnosti písma"), DisplayName("Barva písma")]
        public Color BarvaPisma
        {
            get { return barvaPisma; }
            set { barvaPisma = value; }
        }

        [CategoryAttribute("Vlastnosti písma"), DisplayName("Zarovnání")]
        public Zarovnani ZarovnaniPisma
        {
            get { return zarovnaniPisma; }

            set
            {
                zarovnaniPisma = value;
            }
        }

        [ReadOnly(true)]
        [CategoryAttribute("Odsazení"), DescriptionAttribute("Mezera mezi řádky.")]
        public float Mezera
        {
            get { return mezera; }
            set { mezera = value; }
        }







        //[CategoryAttribute("Pozice bloku"), DisplayName("position")]
        //public Pozice PoziceBloku
        //{
        //    get { return pozice; }
        //    set
        //    {
        //        pozice = value;
        //    }
        //}


        private void SestavFont()
        {
            if (jmenoFontu != null && velikostPisma != 0f)
                font = new Font(jmenoFontu, velikostPisma, stylPisma);
        }

        public void ZmenaVlastnostiFormularem()
        {
            velikostPisma = font.Size;
            jmenoFontu = font.FontFamily;
            stylPisma = font.Style;
        }


        public string SestavitStyl()
        {
            string styl = "";
            if ((stylPisma & FontStyle.Bold) != 0)
            {
                styl += "font-weight=\"bold\" ";
            }
            if ((stylPisma & FontStyle.Underline) != 0)
            {
                styl += "text-decoration=\"underline\" ";
            }
            if ((stylPisma & FontStyle.Italic) != 0)
            {
                styl += "font-style=\"italic\" ";
            }

            switch (zarovnaniPisma)
            {
                case Zarovnani.LEFT:
                    styl += "text-align=\"left\" ";
                    break;
                case Zarovnani.RIGHT:
                    styl += "text-align=\"right\" ";
                    break;
                case Zarovnani.JUSTIFY:
                    styl += "text-align=\"justify\" ";
                    break;
                case Zarovnani.CENTER:
                    styl += "text-align=\"center\" ";
                    break;
                default:
                    styl += "";
                    break;
            }

            //jmenoFontu.Name.ToString().ToLower()
            styl += "font-family=\"" + jmenoFontu.Name.ToString() + "\" font-size=\"" + (int)velikostPisma + "pt\" color=\"" + ColorTranslator.ToHtml(barvaPisma).ToLower() + "\"";
            return styl;
        }
    }
}
