﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using System.Windows.Forms;
using System.Drawing;
using System.Drawing.Drawing2D;

namespace TemplateCreator
{
    class Obdelnik
    {
        private PictureBox hlavniPictureBox;
        public Rectangle obdelnik;
        public bool zapnutoZvetsovaniZmensovani = false;
        private bool jeKliknuto = false;
        public bool presunovat = false;
        private int stareX;
        private int stareY;
        private int velikostNodyProZvetseni = 5;
        
        private UchyceniObdelniku vybranaNoda = UchyceniObdelniku.None;
        

        public bool JeVybran;
        public string Obsah = "";
        public TypObsahu Typ = TypObsahu.None;

        public TabulkaXsl tabulka = null;
        public SlozenyBlokXsl slozenyBlok = null;

        public Format FormatPisma = null;


        public enum TypObsahu
        {
            JednoduchyBlok,
            SlozenyBlok,
            Tabulka,
            None
        };

        private enum UchyceniObdelniku
        {
            HorniStred,
            LevyStred,
            LevaDole,
            LevaNahore,
            PravaNahore,
            PravaStred,
            PravaDole,
            DolniStred,
            None
        };

        public Obdelnik(Rectangle r)
        {
            obdelnik = r;
            jeKliknuto = false;
        }


        public void Kreslit(Graphics g)
        {
            Pen pen;
            Brush brush;
            if (JeVybran)
            {
                pen = new Pen(Color.Black);
                brush = Brushes.Black;
            }
            else
            {
                pen = new Pen(Color.Gray);
                brush = Brushes.Gray;
            }

            if (hlavniPictureBox != null)
            {
                g.DrawRectangle(pen, obdelnik);
                g.DrawString(Obsah, new Font("Arial", 10), brush, new PointF(obdelnik.X + 4, obdelnik.Y + 4));
                if (Obsah != "")

                    switch (this.Typ)
                    {
                        case TypObsahu.JednoduchyBlok:
                            g.DrawImage(Properties.Resources.text_dropcaps, obdelnik.X + obdelnik.Width - 21, obdelnik.Y + 5, 16, 16);
                            break;
                        case TypObsahu.SlozenyBlok:
                            g.DrawImage(Properties.Resources.text_list_bullets, obdelnik.X + obdelnik.Width - 21, obdelnik.Y + 5, 16, 16);
                            break;
                        case TypObsahu.Tabulka:
                            g.DrawImage(Properties.Resources.table, obdelnik.X + obdelnik.Width - 21, obdelnik.Y + 5, 16, 16);
                            break;
                        case TypObsahu.None:
                            g.DrawImage(Properties.Resources.picture_empty, obdelnik.X + obdelnik.Width - 21, obdelnik.Y + 5, 16, 16);
                            break;
                        default:
                            break;
                    }
            }
            


            if (JeVybran && hlavniPictureBox != null)
                foreach (UchyceniObdelniku pos in Enum.GetValues(typeof(UchyceniObdelniku)))
                {
                    g.FillRectangle(Brushes.Black, DejCtverecek(pos));
                    //g.DrawRectangle(new Pen(Color.Red), GetRect(pos));
                }
        }



        public void NastavitPictureBox(PictureBox p)
        {
            this.hlavniPictureBox = p;
            hlavniPictureBox.MouseDown += new MouseEventHandler(hlavniPictureBox_MouseDown);
            hlavniPictureBox.MouseUp += new MouseEventHandler(hlavniPictureBox_MouseUp);
            hlavniPictureBox.MouseMove += new MouseEventHandler(hlavniPictureBox_MouseMove);
            hlavniPictureBox.Paint += new PaintEventHandler(hlavniPictureBox_Paint);
        }

        public void OdeberPictureBox()
        {
            this.hlavniPictureBox = null;
        }

        private void hlavniPictureBox_Paint(object sender, PaintEventArgs e)
        {

            try
            {
                Kreslit(e.Graphics);
            }
            catch (Exception exp)
            {
                System.Console.WriteLine(exp.Message);
            }

        }

        private void hlavniPictureBox_MouseDown(object sender, MouseEventArgs e)
        {
            jeKliknuto = true;

            vybranaNoda = UchyceniObdelniku.None;
            vybranaNoda = DejUchycenouNodu(e.Location);

            if (obdelnik.Contains(new Point(e.X, e.Y)))
            {
                presunovat = true;
            }
            stareX = e.X;
            stareY = e.Y;
        }

        private void hlavniPictureBox_MouseUp(object sender, MouseEventArgs e)
        {
            jeKliknuto = false;
            presunovat = false;
        }

        private void hlavniPictureBox_MouseMove(object sender, MouseEventArgs e)
        {
            ZmenitKurzor(e.Location);
            if (jeKliknuto == false)
            {
                return;
            }

            Rectangle backupRect = obdelnik;

            switch (vybranaNoda)
            {
                case UchyceniObdelniku.LevaNahore:
                    obdelnik.X += e.X - stareX;
                    obdelnik.Width -= e.X - stareX;
                    obdelnik.Y += e.Y - stareY;
                    obdelnik.Height -= e.Y - stareY;
                    break;
                case UchyceniObdelniku.LevyStred:
                    obdelnik.X += e.X - stareX;
                    obdelnik.Width -= e.X - stareX;
                    break;
                case UchyceniObdelniku.LevaDole:
                    obdelnik.Width -= e.X - stareX;
                    obdelnik.X += e.X - stareX;
                    obdelnik.Height += e.Y - stareY;
                    break;
                case UchyceniObdelniku.DolniStred:
                    obdelnik.Height += e.Y - stareY;
                    break;
                case UchyceniObdelniku.PravaNahore:
                    obdelnik.Width += e.X - stareX;
                    obdelnik.Y += e.Y - stareY;
                    obdelnik.Height -= e.Y - stareY;
                    break;
                case UchyceniObdelniku.PravaDole:
                    obdelnik.Width += e.X - stareX;
                    obdelnik.Height += e.Y - stareY;
                    break;
                case UchyceniObdelniku.PravaStred:
                    obdelnik.Width += e.X - stareX;
                    break;

                case UchyceniObdelniku.HorniStred:
                    obdelnik.Y += e.Y - stareY;
                    obdelnik.Height -= e.Y - stareY;
                    break;

                default:
                    if (presunovat)
                    {
                        obdelnik.X = obdelnik.X + e.X - stareX;
                        obdelnik.Y = obdelnik.Y + e.Y - stareY;
                    }
                    break;
            }
            stareX = e.X;
            stareY = e.Y;

            if (obdelnik.Width < 5 || obdelnik.Height < 5)
            {
                obdelnik = backupRect;
            }

            TestJeObdelnikUvnitr();

            if (hlavniPictureBox != null)
                hlavniPictureBox.Invalidate();
        }

        private void TestJeObdelnikUvnitr()
        {
         
            if (obdelnik.X < 0) obdelnik.X = 0;
            if (obdelnik.Y < 0) obdelnik.Y = 0;
            if (obdelnik.Width <= 0) obdelnik.Width = 1;
            if (obdelnik.Height <= 0) obdelnik.Height = 1;

            if (hlavniPictureBox != null)
            {
                if (obdelnik.X + obdelnik.Width > hlavniPictureBox.Width)
                {
                    obdelnik.Width = hlavniPictureBox.Width - obdelnik.X - 1; 
                    if (zapnutoZvetsovaniZmensovani == false)
                    {
                        jeKliknuto = false;
                    }
                }
                if (obdelnik.Y + obdelnik.Height > hlavniPictureBox.Height)
                {
                    obdelnik.Height = hlavniPictureBox.Height - obdelnik.Y - 1;
                    if (zapnutoZvetsovaniZmensovani == false)
                    {
                        jeKliknuto = false;
                    }
                }
            }

        }

        private Rectangle VytvoritNoduProZmenuVelikost(int x, int y)
        {
            return new Rectangle(x - velikostNodyProZvetseni / 2, y - velikostNodyProZvetseni / 2, velikostNodyProZvetseni, velikostNodyProZvetseni);
        }

        private Rectangle DejCtverecek(UchyceniObdelniku p)
        {
            switch (p)
            {
                case UchyceniObdelniku.LevaNahore:
                    return VytvoritNoduProZmenuVelikost(obdelnik.X, obdelnik.Y);

                case UchyceniObdelniku.LevyStred:
                    return VytvoritNoduProZmenuVelikost(obdelnik.X, obdelnik.Y + obdelnik.Height / 2);

                case UchyceniObdelniku.LevaDole:
                    return VytvoritNoduProZmenuVelikost(obdelnik.X, obdelnik.Y + obdelnik.Height);

                case UchyceniObdelniku.DolniStred:
                    return VytvoritNoduProZmenuVelikost(obdelnik.X + obdelnik.Width / 2, obdelnik.Y + obdelnik.Height);

                case UchyceniObdelniku.PravaNahore:
                    return VytvoritNoduProZmenuVelikost(obdelnik.X + obdelnik.Width, obdelnik.Y);

                case UchyceniObdelniku.PravaDole:
                    return VytvoritNoduProZmenuVelikost(obdelnik.X + obdelnik.Width, obdelnik.Y + obdelnik.Height);

                case UchyceniObdelniku.PravaStred:
                    return VytvoritNoduProZmenuVelikost(obdelnik.X + obdelnik.Width, obdelnik.Y + obdelnik.Height / 2);

                case UchyceniObdelniku.HorniStred:
                    return VytvoritNoduProZmenuVelikost(obdelnik.X + obdelnik.Width / 2, obdelnik.Y);
                default:
                    return new Rectangle();
            }
        }

        private UchyceniObdelniku DejUchycenouNodu(Point p)
        {
            foreach (UchyceniObdelniku r in Enum.GetValues(typeof(UchyceniObdelniku)))
            {
                if (DejCtverecek(r).Contains(p))
                {
                    return r;
                }
            }
            return UchyceniObdelniku.None;
        }

        private void ZmenitKurzor(Point p)
        {
            if (hlavniPictureBox != null)
                hlavniPictureBox.Cursor = DejKurzor(DejUchycenouNodu(p));
        }

        /// <summary>
        /// Get cursor for the handle
        /// </summary>
        /// <param name="p"></param>
        /// <returns></returns>
        private Cursor DejKurzor(UchyceniObdelniku p)
        {
            switch (p)
            {
                case UchyceniObdelniku.LevaNahore:
                    return Cursors.SizeNWSE;

                case UchyceniObdelniku.LevyStred:
                    return Cursors.SizeWE;

                case UchyceniObdelniku.LevaDole:
                    return Cursors.SizeNESW;

                case UchyceniObdelniku.DolniStred:
                    return Cursors.SizeNS;

                case UchyceniObdelniku.PravaNahore:
                    return Cursors.SizeNESW;

                case UchyceniObdelniku.PravaDole:
                    return Cursors.SizeNWSE;

                case UchyceniObdelniku.PravaStred:
                    return Cursors.SizeWE;

                case UchyceniObdelniku.HorniStred:
                    return Cursors.SizeNS;
                default:
                    return Cursors.Default;
            }
        }
    }
}
