﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using System.Drawing;

namespace TemplateCreator
{
    class PoleObdelniku
    {
        private IList<Obdelnik> pole;

        public PoleObdelniku()
        {
            pole = new List<Obdelnik>();
        }

        public void PridejObdelnik(Obdelnik o)
        {
            pole.Add(o);
        }

        public int PocetObdelniku
        {
            get { return pole.Count; }
        }

        public IList<Obdelnik> Pole
        {
            get { return pole; }
        }

        public bool OdeberObdelnik(Obdelnik o)
        {
            if (o != null)
            {
                pole.Remove(o);
                return true;
            }
            else
                return false;
        }

        public Obdelnik NajdiNaPozici(Point p)
        {
            foreach (var item in pole)
            {
                if (item.obdelnik.Contains(p))
                {
                    return item;
                }
            }

            return null;
        }

        public string SestavitXsl(Graphics g)
        {
            string xsl = @"<xsl:stylesheet version=""1.0"" xmlns:xsl=""http://www.w3.org/1999/XSL/Transform"" xmlns:fo=""http://www.w3.org/1999/XSL/Format"">
                            <xsl:template match=""/"">
                            <fo:root xmlns:fo=""http://www.w3.org/1999/XSL/Format"">
                                <fo:layout-master-set>
                                <fo:simple-page-master master-name=""simple"" page-height=""29.7cm"" page-width=""21cm"" margin-top=""0cm"" margin-bottom=""0cm"" margin-left=""0cm"" margin-right=""0cm"">
                                    <fo:region-body margin-top=""0cm"" />
                                    <fo:region-before extent=""0cm"" />
                                    <fo:region-after extent=""0cm"" />
                                </fo:simple-page-master>
                                </fo:layout-master-set>
                                <fo:page-sequence master-reference=""simple"">
                                <fo:flow flow-name=""xsl-region-body"">
                                    <xsl:apply-templates />
                                </fo:flow>
                                </fo:page-sequence>
                            </fo:root>
                            </xsl:template>";

            foreach (var item in pole)
            {
                if (item.Obsah == "")
                    throw new Exception();

                if (item.Typ == Obdelnik.TypObsahu.Tabulka)
                {
                    xsl += @"<xsl:template match=""" + item.Obsah + @""">";
                    xsl += @"<fo:block-container position=""absolute"" ";
                    xsl += @"top=""" + PixelToCentimeter(item.obdelnik.Y, g) + @"cm"" left=""" + PixelToCentimeter(item.obdelnik.X, g) + @"cm"" height=""" + PixelToCentimeter(item.obdelnik.Height, g) + @"cm"" width=""" + PixelToCentimeter(item.obdelnik.Width, g) + @"cm"">";
                    xsl += item.tabulka.SestavXsl(g, item.FormatPisma);
                    xsl += "</fo:block-container></xsl:template>";


                }
                else if (item.Typ == Obdelnik.TypObsahu.SlozenyBlok)
                {
                    xsl += @"<xsl:template match=""" + item.Obsah + @""">";
                    xsl += @"<fo:block-container position=""absolute"" ";
                    xsl += @"top=""" + PixelToCentimeter(item.obdelnik.Y, g) + @"cm"" left=""" + PixelToCentimeter(item.obdelnik.X, g) + @"cm"" height=""" + PixelToCentimeter(item.obdelnik.Height, g) + @"cm"" width=""" + PixelToCentimeter(item.obdelnik.Width, g) + @"cm"">";
                    xsl += item.slozenyBlok.SestavXsl(item.FormatPisma);
                    xsl += "</fo:block-container></xsl:template>";
                }
                else
                {
                    string pismo = "font-family=\"" + item.FormatPisma.JmenoFontu.Name.ToString() + "\" font-size=\"" + (int)item.FormatPisma.VelikostPisma + "pt\" color=\"" + ColorTranslator.ToHtml(item.FormatPisma.BarvaPisma).ToLower() + "\" ";
                    string styl = "";
                    if ((item.FormatPisma.StylPisma & FontStyle.Bold) != 0)
                    {
                        styl += "font-weight=\"bold\" ";
                    }
                    if ((item.FormatPisma.StylPisma & FontStyle.Underline) != 0)
                    {
                        styl += "text-decoration=\"underline\" ";
                    }
                    if ((item.FormatPisma.StylPisma & FontStyle.Italic) != 0)
                    {
                        styl += "font-style=\"italic\" ";
                    }

                    string zarovnani = "";
                    switch (item.FormatPisma.ZarovnaniPisma)
                    {
                        case Zarovnani.LEFT:
                            zarovnani += "text-align=\"left\" ";
                            break;
                        case Zarovnani.RIGHT:
                            zarovnani += "text-align=\"right\" ";
                            break;
                        case Zarovnani.JUSTIFY:
                            zarovnani += "text-align=\"justify\" ";
                            break;
                        case Zarovnani.CENTER:
                            zarovnani += "text-align=\"center\" ";
                            break;
                        default:
                            zarovnani += "";
                            break;
                    }
                    xsl += @"<xsl:template match=""" + item.Obsah + @""">";
                    xsl += @"<fo:block-container position=""absolute"" ";
                    xsl += @"top=""" + PixelToCentimeter(item.obdelnik.Y, g) + @"cm"" left=""" + PixelToCentimeter(item.obdelnik.X, g) + @"cm"" height=""" + PixelToCentimeter(item.obdelnik.Height, g) + @"cm"" width=""" + PixelToCentimeter(item.obdelnik.Width, g) + @"cm"">";
                    xsl += "<fo:block " + zarovnani + pismo + styl + "><xsl:apply-templates /></fo:block></fo:block-container></xsl:template>";
                }

            }

            xsl += "</xsl:stylesheet>";
            return xsl;
        }

        int CentimeterToPixel(double Centimeter, Graphics gr)
        {
            double pixel = -1;
            using (Graphics g = gr)
            {
                pixel = Centimeter * g.DpiY / 2.54d;
            }
            return (int)pixel;
        }

        string PixelToCentimeter(int pixel, Graphics gr)
        {
            double centimeter = -1;


            centimeter = (pixel * 2.54d) / gr.DpiY;
            string s = centimeter.ToString();
            s = s.Replace(",", ".");


            return s;
        }

    }
}
